@@ -16,12 +16,10 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Author: Roman Bogorodskiy <bogorodskiy@gmail.com>
  */
 
-#ifndef __BHYVE_DRIVER_H__
-# define __BHYVE_DRIVER_H__
+#ifndef LIBVIRT_BHYVE_DRIVER_H
+# define LIBVIRT_BHYVE_DRIVER_H
 
 # include "capabilities.h"
 # include "bhyve_utils.h"
@@ -34,4 +32,4 @@ unsigned bhyveDriverGetGrubCaps(virConnectPtr conn);
 
 virCapsPtr bhyveDriverGetCapabilities(bhyveConnPtr driver);
 
-#endif /* __BHYVE_DRIVER_H__ */
+#endif /* LIBVIRT_BHYVE_DRIVER_H */
