@@ -96,7 +96,7 @@ static int virNetServerOnceInit(void)
     return 0;
 }
 
-VIR_ONCE_GLOBAL_INIT(virNetServer)
+VIR_ONCE_GLOBAL_INIT(virNetServer);
 
 unsigned long long virNetServerNextClientID(virNetServerPtr srv)
 {
