@@ -24,6 +24,7 @@
 
 #include "virerror.h"
 #include "datatypes.h"
+#include "viralloc.h"
 #include "virlog.h"
 #include "virthread.h"
 #include "virutil.h"
@@ -56,7 +57,8 @@ static virLogPriority virErrorLevelPriority(virErrorLevel level)
 
 
 VIR_ENUM_DECL(virErrorDomain);
-VIR_ENUM_IMPL(virErrorDomain, VIR_ERR_DOMAIN_LAST,
+VIR_ENUM_IMPL(virErrorDomain,
+              VIR_ERR_DOMAIN_LAST,
               "", /* 0 */
               "Xen Driver",
               "Xen Daemon",
