@@ -25,6 +25,7 @@
 #define LIBVIRT_VIRFIREWALLPRIV_H_ALLOW
 #include "virfirewallpriv.h"
 #include "virfirewalld.h"
+#include "viralloc.h"
 #include "virerror.h"
 #include "virutil.h"
 #include "virstring.h"
@@ -41,7 +42,8 @@ typedef struct _virFirewallGroup virFirewallGroup;
 typedef virFirewallGroup *virFirewallGroupPtr;
 
 VIR_ENUM_DECL(virFirewallLayerCommand);
-VIR_ENUM_IMPL(virFirewallLayerCommand, VIR_FIREWALL_LAYER_LAST,
+VIR_ENUM_IMPL(virFirewallLayerCommand,
+              VIR_FIREWALL_LAYER_LAST,
               EBTABLES_PATH,
               IPTABLES_PATH,
               IP6TABLES_PATH,
