@@ -22,7 +22,7 @@
 # define LIBVIRT_VIRMACADDR_H
 
 # include "internal.h"
-# include "viralloc.h"
+# include "virautoclean.h"
 
 # define VIR_MAC_BUFLEN 6
 # define VIR_MAC_HEXLEN (VIR_MAC_BUFLEN * 2)
