@@ -29,6 +29,7 @@
 #include "virtime.h"
 #include "conf/network_conf.h"
 #include "vsh-table.h"
+#include "virenum.h"
 
 #define VIRSH_COMMON_OPT_NETWORK(_helpstr, cflags) \
     {.name = "network", \
@@ -905,11 +906,13 @@ static const vshCmdOptDef opts_network_update[] = {
 };
 
 VIR_ENUM_DECL(virNetworkUpdateCommand);
-VIR_ENUM_IMPL(virNetworkUpdateCommand, VIR_NETWORK_UPDATE_COMMAND_LAST,
+VIR_ENUM_IMPL(virNetworkUpdateCommand,
+              VIR_NETWORK_UPDATE_COMMAND_LAST,
               "none", "modify", "delete", "add-last", "add-first");
 
 VIR_ENUM_DECL(virNetworkSection);
-VIR_ENUM_IMPL(virNetworkSection, VIR_NETWORK_SECTION_LAST,
+VIR_ENUM_IMPL(virNetworkSection,
+              VIR_NETWORK_SECTION_LAST,
               "none", "bridge", "domain", "ip", "ip-dhcp-host",
               "ip-dhcp-range", "forward", "forward-interface",
               "forward-pf", "portgroup", "dns-host", "dns-txt",
